
.. _`Support for PUnit and Units qualifiers`:

Support for PUnit and Units qualifiers
--------------------------------------

.. automodule:: pywbem._units

.. autofunction:: pywbem.siunit_obj

.. autofunction:: pywbem.siunit
